@@ -23,9 +23,9 @@ proc tkeditpr_process_args {} {
             switch -exact -- $opt -server {
                 set TkGnats(ServerInfo) $val
             } -categories {
-                set TkGnats(CategoryFile) $val
+                set TkGnats(CategoryList) $val
             } -submitters {
-                set TkGnats(SubmitterFile) $val
+                set TkGnats(SubmitterList) $val
             } -responsible {
                 set TkGnats(ResponsibleFile) $val
             } -classes {
@@ -178,7 +178,7 @@ proc real_file_report {} {
         if {[check_suppressed_field $f]} {
             continue
         }
-	if {$f != ">Responsible" && ![check_mandatory_field $f]} {
+	if {![check_mandatory_field $f]} {
 	    continue
 	}
         set  val [string trim $frm($f) " \n\t\f!:~-#_?"]
@@ -217,17 +217,21 @@ proc real_file_report {} {
     #
     
     set mail_list ""
+    set changedfields ""
 
     set responsible_addr     [get_responsible_addr $frm(>Responsible)]
     set old_responsible_addr [get_responsible_addr $flds(>Responsible)]
  
     foreach t [concat $Tkeditpr(listboxflds) $Tkeditpr(radioflds)] {
+	#dputs "Comparing frm($t) and flds($t): $frm($t) vs $flds($t)"
         if {$frm($t) != $flds($t)} {
             foreach require {Audit Email Reason} {
                 if {[check_audit_trail_opts $require $t]} {
                     set  require$require 1
+		    append changedfields "$t "
+		    dputs "Field changed: $changedfields"
                     if {$require != "Reason"} {
-                        append ${require}_text "Changed-[get_field_alias $t]-From-To:\t$flds($t)->$frm($t)\n"
+                        append ${require}_text "$t-Changed-[get_field_alias $t]-From-To:\t$flds($t)->$frm($t)\n"
                     }
                 }
             }
@@ -240,14 +244,17 @@ proc real_file_report {} {
             Msg " '|' is an illegal character for the '[get_field_alias $f]' field!"
             return -1
         }
+	#dputs "Comparing frm($f) and flds($f): $frm($f) vs $flds($f)"
         if {$frm($f) != $flds($f)} {
             foreach require {Audit Email Reason} {
                 if {[check_audit_trail_opts $require $f]} {
                     set require$require 1
+		    append changedfields "$f "
+		    dputs "Field changed: $changedfields"
                     if {$require != "Reason"} {
                         set tmptag [get_field_alias $f]
-                        append ${require}_text "Changed-$tmptag-From:\t$flds($f)\n"
-                        append ${require}_text "Changed-$tmptag-To:  \t$frm($f)\n"
+                        append ${require}_text "$f-Changed-$tmptag-From:\t$flds($f)\n"
+                        append ${require}_text "$f-Changed-$tmptag-To:  \t$frm($f)\n"
                     }
                 }
             }
@@ -255,12 +262,15 @@ proc real_file_report {} {
     }
 
     foreach t $Tkeditpr(multitextflds) {
+	#dputs "Comparing frm($t) and flds($t): $frm($t) vs $flds($t)"
         if {[string trim $frm($t)] != [string trim $flds($t)]} {
             foreach require {Audit Email Reason} {
                 if {[check_audit_trail_opts $require $t]} {
                     set  require$require 1
+		    append changedfields "$t "
+		    dputs "Field changed: $changedfields"
                     if {$require != "Reason"} {
-                        append ${require}_text "Changed-[get_field_alias $t]\n"
+                        append ${require}_text "$t-Changed-[get_field_alias $t]\n"
                     }
                 }
             }
@@ -273,8 +283,12 @@ proc real_file_report {} {
         if {[catch {textEntryDialog "Enter reason for changes" "Return to Edit" $whyText 0 .} whyText]} {
             return 1
         }
-        append Audit_text  "Changed-Why:\t[string trim $whyText]\n"
-        append Email_text  "Changed-Why:\t[string trim $whyText]\n"
+
+	foreach f $changedfields {
+	    #dputs "Field changed $f"
+	    append frm($f-Changed-Why) "\n[string trim $whyText]\n"
+	    append Email_text  "$f-Changed-Why:\t[string trim $whyText]\n"
+	}
     }
 
     if {$requireAudit} {
@@ -287,6 +301,7 @@ proc real_file_report {} {
     set done 0
     while {!$done} {
         set stat [real_file_report_$TkGnats(GNATS_ACCESS_METHOD) errs]
+        #puts "stat=$stat errs=$errs"
         if {$stat == 0} {
             set done 1
         } {
@@ -863,7 +878,7 @@ proc edit_window {} {
     message .action.msg -aspect 10000  -relief sunken -bd 1 -text ""
     pack    .action.msg -side left -fill x -expand 1
 
-    # Get the maximum width of the value fields for the radiobar
+    # Get the maximum width of the value fields for the bagged_radiobar
     set Tkeditpr(value_width) 0
     foreach tag $Tkeditpr(radioflds) {
         set f [ftrim $flds($tag)]
@@ -893,11 +908,8 @@ proc edit_window {} {
     radiobar_frame .eflds .eflds.lb
     foreach {efield elist} [list Class $TkGnats(ClassesList) State $TkGnats(StatesList) Priority {low medium high} Severity {non-critical serious critical} Confidential {no yes}] {
         if {[check_suppressed_field $efield] != 1} {
-            if {![info exists TkGnats(${efield}PerRow)]} {
-                set TkGnats(${efield}PerRow) [llength $elist]
-            }
-            radiobar .eflds.lb [string tolower $efield] $efield \
-                    $elist $TkGnats(${efield}PerRow) None > frm $Tkeditpr(value_width)
+            bagged_radiobar .eflds.lb [string tolower $efield] $efield \
+                    $elist None frm $Tkeditpr(value_width)
         }
     }
     pack .eflds.lb -side left -pady 0
@@ -935,16 +947,7 @@ proc edit_window {} {
     fillfrm
 
     tkwait visibility .
-
-    # If a listbox field value is no longer valid (eg a responsible who isn't), a blank value
-    # is placed in the entry field. Warn the user.
-    foreach f $Tkeditpr(listboxflds) {
-        set  val $frm($f)
-        if {$val == ""} {
-            Msg "The value for '[get_field_alias $f]' is no longer valid. Please choose a new value from the list."
-        }
-    }
-        
+    
     if {"$missing_list" != ""} {
         Msg "The following fields were missing from the report but will be added when you Save Changes:\n" [join $missing_list \n]
         set Tkeditpr(parsed_flds) [concat $Tkeditpr(parsed_flds) $missing_list]
@@ -962,12 +965,12 @@ foreach f { tkpr_library.tcl tkprhelp.tcl tkprfont.tcl tkprdatesel.tcl } {
     source $TkGnats(lib)/$f
 }
 
-if {[get_gnats_config] == "-1"} {
+# If TkGnats(GNATS_ACCESS_METHOD) != "socket" then this does nothing
+if {[open_socket_gnatsd 1] == "-1"} {
     exit
 }
 
-# If TkGnats(GNATS_ACCESS_METHOD) != "socket" then this does nothing
-if {[open_socket_gnatsd 1] == "-1"} {
+if {[get_gnats_config] == "-1"} {
     exit
 }
 
