@@ -65,23 +65,10 @@ if {[get_gnats_config] == "-1"} {
     exit
 }
 
-set Query(query_mode) $TkGnats(QueryMode)
+set Query(query_mode) sql2
 #TTD remove me after testing
 #set Query(query_mode) sql2
 
-#
-# numeric --> textual mappings for some query-pr --sql2 fields
-#
-
-set TkGnats(PriorityList)     {high medium low}
-set TkGnats(SeverityList)     {critical serious non-critical}
-set TkGnats(ConfidentialList) {no yes}
-
-set Mappings(State)    $TkGnats(StatesList)
-set Mappings(Priority) $TkGnats(PriorityList)
-set Mappings(Severity) $TkGnats(SeverityList)
-set Mappings(Class)    $TkGnats(ClassesList)
-
 set Query(sort_flds) {
     Number	  Category	Synopsis	Confidential
     Severity	  Priority	Responsible	State   	Class
@@ -99,95 +86,43 @@ set Query(sort_flgs) {
 set Query(default_sort_flds) {Category State Priority Severity Number}
 set Query(user_sort_flds)    {}
 
-set Query(default_query_file) "$TkGnats(UserServerDir)/default-query"
-set Query(default_sort_file)  "$TkGnats(UserServerDir)/default-sort"
-set Query(default_view_file)  "$TkGnats(UserServerDir)/default-view"
+set Query(default_sort_file) "$TkGnats(UserServerDir)/default-sort"
+set Query(default_view_file) "$TkGnats(UserServerDir)/default-view"
 
 # Query listbox headings
-set list_flds_list [list \
-        Number        Id \
-        Submitter-Id  $TkGnats(QuerySubmitter-IdAbbreviation)  \
-        Originator    $TkGnats(QueryOriginatorAbbreviation)    \
-        Responsible   $TkGnats(QueryResponsibleAbbreviation)   \
-        Category      $TkGnats(QueryCategoryAbbreviation)      \
-        Class         $TkGnats(QueryClassAbbreviation)         \
-        Confidential  $TkGnats(QueryConfidentialAbbreviation)  \
-        State         $TkGnats(QueryStateAbbreviation)         \
-        Priority      $TkGnats(QueryPriorityAbbreviation)      \
-        Severity      $TkGnats(QuerySeverityAbbreviation)      \
-        Release       $TkGnats(QueryReleaseAbbreviation)       \
-        Arrival-Date  $TkGnats(QueryArrival-DateAbbreviation)  \
-        Last-Modified $TkGnats(QueryLast-ModifiedAbbreviation) \
-        Closed-Date   $TkGnats(QueryClosed-DateAbbreviation)   \
-        Synopsis      $TkGnats(QuerySynopsisAbbreviation)      \
+set list_flds_list [list  \
+        Number        Id       \
+        Submitter-Id  Sub-Id   \
+        Originator    Originator  \
+        Responsible   Responsible \
+        Category      Category  \
+        Class         Class     \
+        Confidential  Conf      \
+        State         State     \
+        Priority      Priority  \
+        Severity      Severity  \
+        Release       Release   \
+        Arrival-Date  Arr-Date  \
+        Last-Modified Last-Mod  \
+        Closed-Date   Clos-Date \
+        Synopsis      Synopsis  \
         ]
 
 array set list_flds_headings $list_flds_list
 
-# Set the column widths for the listbox.
-proc set_field_width {field} {
-    global TkGnats Query list_flds_headings
-    if {[lsearch -exact "Number Arrival-Date Last-Modified Closed-Date Date-Required Synopsis" $field] >= 0} {
-        return
-    }
-    array set fieldLists {Submitter-Id SubmitterList Category CategoryList Class ClassesList \
-            State StatesList Priority PriorityList Severity SeverityList \
-            Confidential ConfidentialList Responsible ResponsibleList}
-    if {[info exists fieldLists($field)]} {
-        set list $fieldLists($field)
-    } {
-        set list NoList
-    }
-    # set the min width to the width of the listbox heading.
-    set minwidth [string length [get_field_alias $list_flds_headings($field)]]
-    if {[info exists TkGnats($list)]} {
-        # the actual max data length (takes into account any abbreviations for the field).
-        #puts "$field/$list/$TkGnats($list)/[get_max_strlen $TkGnats($list)]"
-        set maxwidth [get_max_abbrev_strlen $field $TkGnats($list)]
-    } {
-        # don't know.
-        set maxwidth 0
-    }
-    if {![info exists TkGnats(Query${field}_width)] || $TkGnats(Query${field}_width) == "min"} {
-        set width $minwidth
-    } elseif {$TkGnats(Query${field}_width) == "max"} {
-        # set to the max data length
-        if {$maxwidth > 0} {
-            set width $maxwidth
-        } {
-            # don't know, so set to the min as documented.
-            set width $minwidth
-        }
-    } {
-        # use the user's value.
-        set width $TkGnats(Query${field}_width)
-    }
-    if {$maxwidth == 0} {
-        set maxwidth $width
-    }
-    set maxwidth [expr {$maxwidth < $minwidth ? $minwidth : $maxwidth}]
-    set width    [expr {$width    < $minwidth ? $minwidth : $width}]
-    set width    [expr {$width    > $maxwidth ? $maxwidth : $width}]
-    set Query(${field}_width) $width
-    #puts "$field=$Query(${field}_width) width=$width minwidth=$minwidth maxwidth=$maxwidth"
-}
-
-foreach field [array names list_flds_headings] {
-    set_field_width $field
-}
-
+#TTD: for custom states and classes, we need to dynamically size the field-width
 array set list_flds_formats  [list \
         Number        "%6d"    \
-        Submitter-Id  " %-$Query(Submitter-Id_width)s"  \
-        Originator    " %-$Query(Originator_width)s" \
-        Responsible   " %-$Query(Responsible_width)s" \
-        Category      " %-$Query(Category_width)s" \
-        Class         " %-$Query(Class_width)s"  \
-        Confidential  " %-$Query(Confidential_width)s"  \
-        State         " %-$Query(State_width)s"  \
-        Priority      " %-$Query(Priority_width)s"  \
-        Severity      " %-$Query(Severity_width)s" \
-        Release       " %-$Query(Release_width)s" \
+        Submitter-Id  " %-8s"  \
+        Originator    " %-10s" \
+        Responsible   " %-11s" \
+        Category      " %-16s" \
+        Class         " %-5s"  \
+        Confidential  " %-4s"  \
+        State         " %-9s"  \
+        Priority      " %-8s"  \
+        Severity      " %-12s" \
+        Release       " %-28s" \
         Arrival-Date  " %-10s" \
         Last-Modified " %-10s" \
         Closed-Date   " %-10s" \
@@ -212,47 +147,19 @@ array set list_flds_defaults  [list \
         Synopsis      "Synopsis"    \
 ]
 
-array set gnatsd_commands [list \
-        Submitter-Id SUBM \
-        Originator   ORIG \
-        Responsible  RESP \
-        Category     CATG \
-        Class        CLSS \
-        Confidential CONF \
-        State        STAT \
-        Priority     PRIO \
-        Severity     SVTY \
-        Release      RLSE \
-        Synopsis     SYNP \
-        Multitext    MTXT \
-        Keywords     KYWD \
-        $TkGnats(Quarter)    QRTR \
-        Date-Required.after  AFTR \
-        Date-Required.before BFOR \
-        Arrival-Date.after   ARAF \
-        Arrival-Date.before  ABFR \
-        Last-Modified.after  MAFT \
-        Last-Modified.before MBFR \
-        Closed-Date.after    CAFT \
-        Closed-Date.before   CBFR \
-]        
-
 if {$TkGnats(ReleaseBased)} {
     set Query(sort_flds) [concat $Query(sort_flds) Keywords $TkGnats(Quarter) Date-Required]
     set Query(sort_flgs) [concat $Query(sort_flgs) "" "" ""]
     set list_flds_list   [concat [lrange $list_flds_list 0 [expr [llength $list_flds_list] - 3]] \
-            Keywords          $TkGnats(QueryKeywordsAbbreviation) \
-            $TkGnats(Quarter) $TkGnats(QueryQuarterAbbreviation)  \
-            Date-Required     $TkGnats(QueryDate-RequiredAbbreviation) \
-            Synopsis          $TkGnats(QuerySynopsisAbbreviation) \
+            Keywords Keywords \
+            $TkGnats(Quarter) $TkGnats(Quarter) \
+            Date-Required     Date-Req \
+            Synopsis          Synopsis \
             ]
     array set list_flds_headings $list_flds_list
-    foreach field [list Keywords $TkGnats(Quarter) Date-Required] {
-        set_field_width $field
-    }
     array set list_flds_formats [list  \
-            Keywords          " %-$Query(Keywords_width)s"  \
-            $TkGnats(Quarter) " %-$Query($TkGnats(Quarter)_width)s"  \
+            Keywords          " %-9s"  \
+            $TkGnats(Quarter) " %-9s"  \
             Date-Required     " %-10s" \
             ]
     array set list_flds_defaults  [list \
@@ -262,11 +169,7 @@ if {$TkGnats(ReleaseBased)} {
             ]
 }
 
-# we use these widths as "string range 0 $width", so subtract 1.
-foreach var [array names Query *_width] {
-    incr Query($var) -1
-}
-
+set Query(orig_wid) [expr [string trim $list_flds_formats(Originator) " %-s"] - 1]
 if {[info exists TkGnats(QueryOriginatorFormat)] && \
         $TkGnats(QueryOriginatorFormat) == "short"} {
     set Query(orig_short) 1
@@ -276,6 +179,16 @@ if {[info exists TkGnats(QueryOriginatorFormat)] && \
     
 set Query(done_msg) ""
 
+#
+# numeric --> textual mappings for some query-pr --sql2 fields
+#
+####set Mappings(State)    {open analyzed suspended feedback closed}
+set Mappings(State)    $TkGnats(StatesList)
+set Mappings(Priority) {high medium low}
+set Mappings(Severity) {critical serious non-critical}
+####set Mappings(Class)    {sw-bug doc-bug support change-request mistaken duplicate}
+set Mappings(Class)    $TkGnats(ClassesList)
+
 # List of entry widgets for traverse key binding
 set Query(tlist) {}
 
@@ -300,19 +213,6 @@ proc headingMsg {s} {
     update
 }
 
-proc get_default_query {} {
-    global Query
-    if {$Query(default_query_file) != "" && [file exists $Query(default_query_file)]} {
-        if {[catch {uplevel \#0 source $Query(default_query_file)} rep]}  {
-            set Query(done_msg) "Startup Default query FAILED!"
-            Msg "Error executing Startup Default query:\n" "$rep"
-        } {
-            set Query(done_msg) "Startup Default query"
-            perform_query_cmd
-        }
-    }
-}
-
 proc get_default_sort_criteria {} {
     global Query
     set Query(user_sort_flds) $Query(default_sort_flds)
@@ -364,7 +264,11 @@ proc query_from_selection {} {
     if {$TkGnats(GNATS_ACCESS_METHOD) == "batch"} {
         set Query(query_pr_opts) "$prid_list"
     } {
-        set Query(query_pr_opts) "$Query(query_mode) $prid_list"
+        set Query(query_pr_opts) ""
+	foreach prid $prid_list {
+	    append Query(query_pr_opts) "Number==$prid_list|"
+	}
+	append Query(query_pr_opts) " "
     }
     set Query(by_id_only) 1
     set Query(done_msg) "query from selection for Id $prid_list"
@@ -628,10 +532,8 @@ proc save_query_view_fields {sfout} {
 
 proc update_query_view_fields {} {
     global Query list_flds_selected list_flds_heading
-    busy_cursor set
     set_query_view_fields
     query_fill_listbox
-    busy_cursor clear
 }
 
 proc set_query_view_fields {} {
@@ -890,7 +792,7 @@ proc selection_Edit_cmd {w} {
 	TkGnats_exec $TkGnats(WISHPATH) $TkGnats(lib)/tkeditpr.tcl -prid $prid \
                 -server $TkGnats(ServerInfo) \
                 -classes $TkGnats(ClassesFile) -states $TkGnats(StatesFile) \
-                -categories $TkGnats(CategoryFile) -submitters $TkGnats(SubmitterFile) \
+                -categories $TkGnats(CategoryList) -submitters $TkGnats(SubmitterList) \
                 -responsible $TkGnats(ResponsibleFile) &
 	schedule_reap
 	after 2250 {headingMsg " " ; busy_cursor clear}
@@ -907,7 +809,7 @@ proc selection_View_Formatted_cmd {w} {
 	TkGnats_exec $TkGnats(WISHPATH) $TkGnats(lib)/tkviewpr.tcl -prid $prid \
                 -server $TkGnats(ServerInfo) \
                 -classes $TkGnats(ClassesFile) -states $TkGnats(StatesFile) \
-                -categories $TkGnats(CategoryFile) -submitters $TkGnats(SubmitterFile) \
+                -categories $TkGnats(CategoryList) -submitters $TkGnats(SubmitterList) \
                 -responsible $TkGnats(ResponsibleFile) &
 	schedule_reap
 	after 2250 {headingMsg " " ; busy_cursor clear}
@@ -924,7 +826,7 @@ proc selection_View_Raw_cmd {w} {
 	TkGnats_exec $TkGnats(WISHPATH) $TkGnats(lib)/tkviewpr.tcl -prid $prid -raw 1 \
                 -server $TkGnats(ServerInfo) \
                 -classes $TkGnats(ClassesFile) -states $TkGnats(StatesFile) \
-                -categories $TkGnats(CategoryFile) -submitters $TkGnats(SubmitterFile) \
+                -categories $TkGnats(CategoryList) -submitters $TkGnats(SubmitterList) \
                 -responsible $TkGnats(ResponsibleFile) &
 	schedule_reap
 	after 2250 {headingMsg " " ; busy_cursor clear}
@@ -949,7 +851,7 @@ proc build_query_trailer {} {
 }
 
 proc build_date_query_qualifier {tag d when} {
-    global TkGnats Query gnatsd_commands
+    global TkGnats Query 
     set mode $TkGnats(GNATS_ACCESS_METHOD)
     set times(after)  "00:00"
     set times(before) "23:59"
@@ -968,7 +870,8 @@ proc build_date_query_qualifier {tag d when} {
         append date " $times($when)"
     }
     if {$mode == "socket"} {
-        set str "$gnatsd_commands($tag.$when) $date"
+	# XXX GNATS 4
+        #set str "$gnatsd_commands($tag.$when) $date"
     } {
         set str "--$var=$date"
     }
@@ -976,7 +879,10 @@ proc build_date_query_qualifier {tag d when} {
 }
     
 proc build_regex_query_qualifier {subclauseop type tag lst regexp} {
-    global TkGnats Query gnatsd_commands
+    global TkGnats Query 
+
+    dputs "build_regex_query_qualifier: $subclauseop $type $tag $lst $regexp"
+
     if {$tag == "Submitter-Id"} {
         set tag2 Submitter
     } {
@@ -999,13 +905,13 @@ proc build_regex_query_qualifier {subclauseop type tag lst regexp} {
 	# first clause: put in leading option stuff
 	if {"$subclausestr" == ""} {
             if {$mode == "socket"} {
-                set subclausestr "$gnatsd_commands($tag) "
+                set subclausestr ""
             } {
                 set subclausestr [format "--%s=" [string tolower $tag2]]
             }
 	}
 	switch -exact -- $type -exact {
-	    append subclausestr "$subclauseopstr^$data\$"
+	    append subclausestr "$subclauseopstr $tag = \"$data\""
 	} -glob {
 	    append subclausestr "$subclauseopstr$data"
 	}
@@ -1015,7 +921,7 @@ proc build_regex_query_qualifier {subclauseop type tag lst regexp} {
 	# no clauses were written
         if {"$regexp" != "" } {
             if {$mode == "socket"} {
-                set subclausestr "$gnatsd_commands($tag) $regexp"
+                set subclausestr "$tag = $regexp"
             } {
                 set subclausestr [format "--%s=" [string tolower $tag2]]$regexp
             }
@@ -1185,11 +1091,13 @@ proc get_save_file_name {title} {
     return $p
 }
 
-proc save_query_cmd {mode {sfname {}}} {
+proc save_query_cmd {mode} {
     global TkGnats Query Tkprfolder lbpath
 
     if {$mode == "save"} {
-        while {"$sfname" == ""} {
+        set p ""
+        while {"$p" == ""} {
+            ###set p [file tail [get_save_file_name Query]]
             set p [get_save_file_name Query]
             if {"$p" == ""} {
                 headingMsg "Save cancelled"
@@ -1205,7 +1113,7 @@ proc save_query_cmd {mode {sfname {}}} {
                 bell
                 if {[tk_dialog .tkprfolder_delete "Confirm_Save" "$p already exists" \
                         "warning" -1 "Overwrite" "Cancel"] != 0} {
-                    set sfname ""
+                    set p ""
                 }
             }
         }
@@ -1219,7 +1127,11 @@ proc save_query_cmd {mode {sfname {}}} {
         if {$mode != "save"} {
             set Query(default__query) [list proc default__query {flds} {return 1}]
             if {$TkGnats(GNATS_ACCESS_METHOD) == "batch"} {
-                set Query(query_pr_opts) "$prid_list"
+		set Query(query_pr_opts) ""
+		foreach prid $prid_list {
+		    append Query(query_pr_opts) "Number==$prid_list|"
+		}
+		append Query(query_pr_opts) " "
             } {
                 set Query(query_pr_opts) "$Query(query_mode) $prid_list"
             }
@@ -1390,7 +1302,7 @@ proc clear_query_cmd {{headingmsgflag ""}} {
 
 proc query_fill_listbox {} {
     global TkGnats Query Mappings \
-            lbpath list_flds_formats list_flds_format list_flds_list list_flds_selected list_flds_headings
+            lbpath list_flds_formats list_flds_format list_flds_list list_flds_selected
 
     if {![info exists Query(PrList)]} {
         return
@@ -1398,9 +1310,12 @@ proc query_fill_listbox {} {
 
     #puts [join $Query(PrList) \n]
     
-    foreach fld [array names list_flds_headings] {
-        if {[info exists TkGnats(Query${fld}Abbreviations)]} {
-            array set ${fld}_vals $TkGnats(Query${fld}Abbreviations)
+    array set Class_vals \
+            [list sw-bug sw doc-bug doc change-request chg support sup mistaken mis duplicate dup]
+    
+    foreach fld "Class State" {
+        if {[info exists TkGnats(${fld}Abbreviations)]} {
+            array set ${fld}_vals $TkGnats(${fld}Abbreviations)
         }
     }
 
@@ -1425,7 +1340,7 @@ proc query_fill_listbox {} {
 	#
 	set l    [split $ln "|"]
 	set llen [llength $l]
-        set len  16
+        set len  19
         if {$TkGnats(ReleaseBased)} {
             incr len 3
         }
@@ -1496,34 +1411,31 @@ proc query_fill_listbox {} {
                 for {set i 0} {$i < [llength $list_flds_list]} {incr i 2} {
                     set x [lindex $list_flds_list $i]
                     if {$list_flds_selected($x) != ""} {
-                        if {($x == "Arrival-Date") || ($x == "Last-Modified") || \
+                        if {$x == "Originator"} {
+                            set orig [extract_full_name_from_address $flds($x)]
+                            if {[string first "@" $orig] > 0} {
+                                set orig [lindex [split $flds($x) "@"] 0]
+                            }
+                            set orig [string trim $orig]
+                            if {$Query(orig_short)} {
+                                # The following line reverts to old-style single name
+                                set orig [lindex [split $orig " "] 0]
+                            }
+                            append ln [format $list_flds_formats($x) \
+                                    [string range $orig 0 $Query(orig_wid)]]
+                        } elseif {($x == "Arrival-Date") || ($x == "Last-Modified") || \
                                 ($x == "Closed-Date") || ($x == "Date-Required")} {
                             append ln [format $list_flds_formats($x) \
                                     [lindex [split $flds($x) "@ "] 0]]
-                        } {
-                            set val $flds($x)
-                            if {$x == "Originator"} {
-                                set val [extract_full_name_from_address $flds($x)]
-                                if {[string first "@" $val] > 0} {
-                                    set val [lindex [split $flds($x) "@"] 0]
-                                }
-                                set val [string trim $val]
-                                if {$Query(orig_short)} {
-                                    # The following line reverts to old-style single name
-                                    set val [lindex [split $val " "] 0]
-                                }
-                            }
-                            if {[info exists ${x}_vals]} {
-                                if {[info exists [subst ${x}_vals($flds($x))]]} {
-                                    set val [subst $${x}_vals($flds($x))]
-                                }
-                            }
-                            if {[info exists Query(${x}_width)]} {
-                                append ln [format $list_flds_formats($x) \
-                                        [string range $val 0 $Query(${x}_width)]]
+                        } elseif {[info exists ${x}_vals]} {
+                            if {[info exists [subst ${x}_vals($flds($x))]]} {
+                                set val [subst $${x}_vals($flds($x))]
                             } {
-                                append ln [format $list_flds_formats($x) $val]
+                                set val $flds($x)
                             }
+                            append ln [format $list_flds_formats($x) $val]
+                        } {
+                            append ln [format $list_flds_formats($x) $flds($x)]
                         }
                         append list_flds_format $list_flds_formats($x)
                         #puts "$x width: [string trim $list_flds_formats($x) "%- sd"]"
@@ -1558,10 +1470,8 @@ proc query_fill_listbox {} {
 
 proc perform_sort_cmd {} {
     global Query
-    busy_cursor set
     sort_cmd
     query_fill_listbox
-    busy_cursor clear
 }
 
 proc sort_cmd {} {
@@ -1658,15 +1568,18 @@ proc query_cmd_socket {} {
         return
     }
     
-    if {[lindex [lindex $Query(query_pr_opts) 0] 0] == $Query(query_mode)} {
-        set clist "RSET"
-        set doit  $Query(query_pr_opts)
-    } {
-        set clist "RSET $Query(query_pr_opts)"
-        set doit  $Query(query_mode)
+    dputs "Query_pr_opts $Query(query_pr_opts)"
+    set clist { "RSET" "QFMT sql2" }
+
+    foreach condition $Query(query_pr_opts) {
+	lappend clist [concat EXPR $condition]
+	dputs "clist now $clist"
     }
 
+    set doit  ""
+
     foreach cmd $clist {
+	dputs "query sending $cmd"
         puts $s $cmd
         set rep [get_socket_reply $s]
         if {![string match 210* [lindex $rep 0]]} {
@@ -1677,30 +1590,21 @@ proc query_cmd_socket {} {
     }
 
     set prdata ""
-    set n [expr [llength $doit] - 1]
-    if {$n == 0} {
-        set n 1
-    }
-    # TTD: There's a bug in gnatsd. If you send "SQL2 23 547" and 547 doesn't exist,
-    #      it gives 410 error and closes the socket. We need to do one PR at a time.
-    #      This just affects selection query and Number field query.
-    for {set i 1} {$i <= $n} {incr i} {
-        puts $s "[lindex $doit 0] [lindex $doit $i]"
+
+        puts $s "QUER"
         
         set rep [get_socket_reply $s]
         if {[string match 440* [lindex $rep 0]]} {
-            if {$n == 1} {
-                close_socket_gnatsd
-                return
-            }
-        } elseif {![string match 2* [lindex $rep 0]]} {
+            close_socket_gnatsd
+	    return
+        } elseif {![string match 30* [lindex $rep 0]]} {
             Msg "GNATSD error on cmd: $doit\n" "[join $rep \n]"
             close_socket_gnatsd
             return
         } {
             set prdata [concat $prdata [get_gnatsd_reply_dot_ended $s]]
         }
-    }
+
     set Query(PrList) $prdata
 
     catch {close_socket_gnatsd}
@@ -1864,13 +1768,6 @@ proc set_query_sort_fields {} {
             $Query(default_sort_flds) $Query(default_sort_file)
 }
 
-proc save_default_query {} {
-    global Query
-    save_query_cmd save $Query(default_query_file)
-    Notice "Startup Default query saved."
-    build_query_menu
-}
-
 proc save_default_view {} {
     global Query list_flds_selected
     # save default-view file
@@ -1878,14 +1775,12 @@ proc save_default_view {} {
     puts  $sfout "array set list_flds_selected \{[array get list_flds_selected]\}"
     close $sfout
     Notice "Default fields saved."
-    build_view_menu
 }
 
 proc save_default_sort {} {
     global Query
     save_sort_fields $Query(default_sort_file)  $Query(user_sort_flds)
     Notice "Default sort saved."
-    build_sort_menu
 }
 
 proc exit_cmd {} {
@@ -1918,15 +1813,8 @@ menu       .mframe.file.m
         -command {TkGnats_exec $TkGnats(WISHPATH) $TkGnats(lib)/tksendpr.tcl \
         -server $TkGnats(ServerInfo) \
         -classes $TkGnats(ClassesFile) -states $TkGnats(StatesFile) \
-        -categories $TkGnats(CategoryFile) -submitters $TkGnats(SubmitterFile) \
+        -categories $TkGnats(CategoryList) -submitters $TkGnats(SubmitterList) \
         -responsible $TkGnats(ResponsibleFile) &; schedule_reap}
-
-# Add optional buttons to the top of the main menu
-if {[info exists TkGnats(QueryFileMenu)]} {
-    .mframe.file.m add separator
-    eval $TkGnats(QueryFileMenu)
-}
-
 .mframe.file.m add separator
 .mframe.file.m add command -label "Exit" \
         -command exit_cmd
@@ -1975,12 +1863,9 @@ pack .mframe.help -side right
 
 frame .eflds
 radiobar_frame .eflds .eflds.lb
-foreach {efield elist} [list Class $TkGnats(ClassesList) State $TkGnats(StatesList) Priority $TkGnats(PriorityList) Severity $TkGnats(SeverityList) Confidential $TkGnats(ConfidentialList)] {
+foreach {efield elist} [list Class $TkGnats(ClassesList) State $TkGnats(StatesList) Priority {low medium high} Severity {non-critical serious critical} Confidential {no yes}] {
     if {![check_suppressed_field $efield]} {
-        if {![info exists TkGnats(${efield}PerRow)]} {
-            set TkGnats(${efield}PerRow) [llength $elist]
-        }
-        checkbar .eflds.lb [string tolower $efield] $efield $elist $TkGnats(${efield}PerRow) All
+        checkbar .eflds.lb [string tolower $efield] $efield $elist All
     }
 }
 pack .eflds -side top  -padx  0 -fill x -anchor w
@@ -2114,10 +1999,6 @@ proc build_query_menu {} {
     }
     menu .menu.query.m
     .menu.query.m  configure  -disabledforeground [.menu.query.m cget -foreground]
-    if {[file exists $Query(default_query_file)]} {
-        .menu.query.m add command -label "Do Startup Default Query" -command get_default_query
-        .menu.query.m add separator
-    }
     .menu.query.m add command -label "Do Query"        -command perform_query_cmd
     .menu.query.m add command -label "Query Selection" -command query_from_selection
     .menu.query.m add command -label "Clear Widgets"   -command clear_query_cmd
@@ -2126,8 +2007,8 @@ proc build_query_menu {} {
     .menu.query.m add cascade -label "Save Current"    -menu   .menu.query.m.save
     .menu.query.m add command -label "Manage Saved..." -command folder_view_query_cmd
     menu .menu.query.m.save -tearoff no
-    .menu.query.m.save add command -label "To Saved Queries Menu..." -command folder_save_query_cmd
-    .menu.query.m.save add command -label "As Startup Default"       -command save_default_query
+    .menu.query.m.save add command -label "To Saved Queries Menu..." \
+            -command folder_save_query_cmd
 
     .menu.query.m add separator
     .menu.query.m add cascade -label "Query For" -menu .menu.query.m.query
@@ -2158,7 +2039,7 @@ build_query_menu
 #
 
 proc build_sort_menu {} {
-    global TkGnats Tkprfolder Query
+    global TkGnats Tkprfolder
     if {[winfo exists .menu.sort.m]} {
         destroy .menu.sort.m
     } {
@@ -2166,13 +2047,6 @@ proc build_sort_menu {} {
     }
     menu .menu.sort.m
     .menu.sort.m  configure  -disabledforeground [.menu.sort.m cget -foreground]
-    if {[file exists $Query(default_sort_file)]} {
-        .menu.sort.m add command -label "Reset to Startup Defaults" \
-                -command "source $Query(default_sort_file)
-        set Query(done_msg) \"sort by Startup Default\"
-        perform_sort_cmd"
-        .menu.sort.m add separator
-    }
     .menu.sort.m add command -label "New..."          -command set_query_sort_fields
 
     .menu.sort.m add separator
@@ -2209,35 +2083,25 @@ build_sort_menu
 # Fields Menu
 #
 
-proc build_view_menu {} {
-    global TkGnats Tkprfolder Query list_flds_selected list_flds_list
-    if {[winfo exists .menu.view.m]} {
-        destroy .menu.view.m
-    } {
-        menubutton .menu.view -text "Fields" -menu .menu.view.m -underline 0
-    }
-    menu .menu.view.m
-    if {[file exists $Query(default_view_file)]} {
-        .menu.view.m add command -label "Reset to Startup Defaults" \
-                -command "source $Query(default_view_file)
-        update_query_view_fields"
-        .menu.view.m add separator
-    }
-    .menu.view.m add cascade -label "Save Current" -menu .menu.view.m.save
-    menu .menu.view.m.save -tearoff no
-    .menu.view.m.save add command -label "As Startup Default" -command save_default_view
-    .menu.view.m add separator
-    set list_flds_selected(Number) Number
-    for {set i 2} {$i < [llength $list_flds_list]} {incr i 2} {
-        set x [lindex $list_flds_list $i]
-        if {![check_suppressed_field $x]} {
-            .menu.view.m add checkbutton -label [get_field_alias $x] \
-                    -command "update_query_view_fields" \
-                    -offvalue "" -onvalue $x -variable [format "list_flds_selected(%s)" $x]
-        }
+menubutton .menu.view -text "Fields" -menu .menu.view.m -underline 0
+menu       .menu.view.m
+.menu.view.m add cascade -label "Save Current" -menu .menu.view.m.save
+menu .menu.view.m.save -tearoff no
+.menu.view.m.save add command -label "As Startup Default" -command save_default_view
+.menu.view.m add separator
+set list_flds_selected(Number) Number
+for {set i 2} {$i < [llength $list_flds_list]} {incr i 2} {
+    set x [lindex $list_flds_list $i]
+    #if {![check_suppressed_field $x]} {
+    #    .menu.view.m add checkbutton -label $x -command "update_query_view_fields" \
+    #            -offvalue "" -onvalue $x -variable [format "list_flds_selected(%s)" $x]
+    #}
+    if {![check_suppressed_field $x]} {
+        .menu.view.m add checkbutton -label [get_field_alias $x] \
+                -command "update_query_view_fields" \
+                -offvalue "" -onvalue $x -variable [format "list_flds_selected(%s)" $x]
     }
 }
-build_view_menu
 
 #
 # Print Menu
@@ -2339,5 +2203,3 @@ wm title      . "TkGnats - [lindex $TkGnats(ServerInfo) 0]"
 wm iconbitmap . @$TkGnats(lib)/tkquerypr.xbm
 ###wm iconname   . "$TkGnats(LogName)'s tkquerypr"
 wm iconname   . "[lindex $TkGnats(ServerInfo) 0]"
-
-get_default_query
