@@ -19,14 +19,14 @@
 # along with GNU GNATS; see the file COPYING.  If not, write to
 # the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 
-prog=`basename $0`
-USAGE="Usage: $prog [-h] [-d gnats_root] arguments
+prog=at-pr
+USAGE="Usage: $prog [-h|--help] [-d|--database database_name] arguments
 
  Arguments coming in are (all are required):
 
  1 - response time
  2 - PR number
- 3 - path to the PR file
+ 3 - path to the PR file (unused)
  4 - submitter-id
  5 - full name of the submitter
  6 - contact for the submitter
@@ -41,7 +41,7 @@ then
   exit 1
 fi
 
-if [ "$1" = "-h" -o "$1" = "--help" ]
+if [ "x$1" = "x-h" -o "x$1" = "x--help" ]
 then
   echo "$USAGE"
   exit 0
@@ -50,7 +50,7 @@ fi
 # process command line options
 while [ $# -gt 7 ]; do
   case "$1" in
-    -d | --directory)
+    -d | --database)
       if [ $# -eq 8 ]
       then 
         echo "ERROR: value required for $1 option" >&2
@@ -58,90 +58,66 @@ while [ $# -gt 7 ]; do
         exit 1
       fi
       shift 
-      GNATS_ROOT="$1" ;;
-    -d=* | --directory=*) GNATS_ROOT="`echo $1 | sed 's/^[-a-z]*=//'`" ;;
+      GNATSDB="$1" ;;
+    -d=* | --database=*) GNATSDB="`echo $1 | sed 's/^[-a-z]*=//'`" ;;
 
     -*) echo "$USAGE" >&2; exit 1 ;;
   esac
   shift
 done
 
-GNATS_ROOT=${GNATS_ROOT:-xGNATS_ROOTx} ; export GNATS_ROOT
+export GNATSDB
 VERSION=xVERSIONx
-LIBEXECDIR=xLIBEXECDIRx
-MAIL_AGENT="xMAIL_AGENTx"
-GNATS_USER="xGNATS_USERx"
+LIBEXECDIR="xLIBEXECDIRx/gnats"
+QUERY_PR="xBINDIRx/query-pr"
 
-STATES_FILE=${GNATS_ROOT}/gnats-adm/states
+eval `$QUERY_PR --print-sh-vars`
 
-# Newer config information?
-[ -f ${GNATS_ROOT}/gnats-adm/config ] && . ${GNATS_ROOT}/gnats-adm/config
+if [ "x$GNATSDB_VALID" = x0 ]
+then
+    echo "Invalid database name $GNATSDB"
+    exit 1
+fi
 
 if [ $# != 7 ]; then
   echo "ERROR: $prog called with the incorrect number of arguments" >&2
   echo "$USAGE" >&2
   exit 1
 fi
- 
-if [ ! -d $GNATS_ROOT ]; then
-  echo "ERROR: $prog GNATS base directory $GNATS_ROOT does not exist." >&2
-  echo "$USAGE" >&2
-  exit 1
+
+# See if the PR number is still valid.
+
+$QUERY_PR --format Number $2 > /dev/null 2>&1
+
+if [ $? ! = 0 ]
+then
+    # Maybe the PR is gone?
+    exit 0
 fi
-
-# If the PR file isn't there, it may have been reclassified, so don't
-# fret about it.
-if [ ! -f $3 ]; then exit 0; fi
-
+ 
 # Grab the current state of the PR, and the synopsis.
-STATE=`grep '^>State:' $3 | sed -e 's,^>State:[ 	]*,,g'`
-SYNOPSIS=`grep '^>Synopsis:' $3 | sed -e 's,^>Synopsis:[ 	]*,,g'`
-RESPONSIBLE=`grep '^>Responsible:' $3 | sed -e 's,^>Responsible:[ 	]*,,g'`
-RESP_ADDR=`$LIBEXECDIR/gnats/pr-addr "$RESPONSIBLE"`
+
+# XXX ??? !!! Instead  of calling query-pr 3 times, why not do it once and
+# use read or something?
+
+STATE="`$QUERY_PR --format State $2`"
+SYNOPSIS="`$QUERY_PR --format Synopsis $2`"
+RESPONSIBLE="`$QUERY_PR --format Responsible $2`"
+RESP_ADDR=`$LIBEXECDIR/pr-addr "$RESPONSIBLE"`
 
 # $DEBUG_MODE is set to 0 when debug is off in the config file
 if [ "x$DEBUG_MODE" = "x1" ]; then
-  STEALTH_HEADER="From: $GNATS_USER (GNATS Management)
-To: $GNATS_ADMIN
+  STEALTH_HEADER="From: $7 (GNATS Management)
+To: $7
 Subject: mail output from at-pr
 
 
 "
 fi
 
-# Read the default (first) state from the gnats-adm/states file.
-get_default_state ()
-{
-    if [ ! -f ${STATES_FILE} ]; then
-      echo "open";
-      return 0;
-    fi
-
-    LINES=`grep '^[A-Za-z0-9_.-]' ${STATES_FILE} 2>/dev/null`
-
-    if [ -z "${LINES}" ]; then
-      echo "open"
-      return 0;
-    fi
-
-    # else get the first state
-
-    # Yes, this is as gross as you think it is.
-    # Tried to use `read', but that didn't work...
-    SAVED_IFS=${IFS}
-    IFS="${IFS}:"
-    for name in ${LINES}
-    do
-        echo "${name}"
-        IFS=${SAVED_IFS}
-        break
-    done
-}
-OPEN_STATE=`get_default_state`
-
-if [ "$STATE" = "${OPEN_STATE}" ]; then
-  $MAIL_AGENT << __EOF__
-${STEALTH_HEADER}From: $GNATS_USER (GNATS Management)
+if [ "$STATE" = "${DEFAULTSTATE}" ]; then
+  $LIBEXECDIR/mail-agent << __EOF__
+${STEALTH_HEADER}From: $7 (GNATS Management)
 To: $6, $RESP_ADDR, $7
 Subject: PR $2 not analyzed in $1 hours
 
